@@ -1,6 +1,6 @@
 """Package that automatically caches and dispatch serialization and deserialization to the correct functions depending on the extension."""
 from .cache import Cache, cache
-from .exception import SerializationException
+from .backends import SerializationException, DeserializationException
 
 import logging
 logging.getLogger(__name__).addHandler(logging.NullHandler())
@@ -9,4 +9,5 @@ __all__ = [
     "Cache", 
     "cache", 
     "SerializationException",
+    "DeserializationException",
 ]
\ No newline at end of file
